@@ -96,7 +96,7 @@ class CheckLex():
         second_lex_error_list = None
         lex_errors = []
 
-        if not self.lex_error_list and self.__first_error and self.attempts < 3:
+        if not self.lex_error_list and self.__first_error and self.attempts < 3 and self.latex_string:
 
             helpers.debug("\n[check_grammar_lex.py] check_correct_lex() | There's no previous error. Searching the first one.")
 
@@ -118,7 +118,7 @@ class CheckLex():
 
                 self.__attempt_to_fix_error(lex_errors)
 
-        elif self.lex_error_list and not self.__first_error and self.attempts < 3:
+        elif self.lex_error_list and not self.__first_error and self.attempts < 3 and self.latex_string:
             helpers.debug("\n[check_grammar_lex.py] check_correct_lex() | There's previous error. Searching for new errors.")
 
             second_lex_error_list = lex.LatexLexer(self.latex_string)
@@ -147,7 +147,7 @@ class CheckLex():
 
                 self.__attempt_to_fix_error(lex_errors)
 
-        elif self.lex_error_list and self.attempts >= 3:
+        elif (self.lex_error_list and self.attempts >= 3) or not self.latex_string:
             raise LexicalError({
                 'latex': self.latex,
                 'latex_list': self.latex_list,
@@ -186,7 +186,7 @@ class CheckLex():
         helpers.debug("[check_grammar_lex.py] self.__attempt_to_fix_error() | Updated lex error history: {0}".format(self.lex_errors_history))
 
         # Se ...
-        if update_latex_string:
-            self.latex_string = update_latex_string
-            self.attempts += 1
-            return self.check_correct_lex()
\ No newline at end of file
+        # if update_latex_string:
+        self.latex_string = update_latex_string
+        self.attempts += 1
+        return self.check_correct_lex()
\ No newline at end of file
