@@ -27,14 +27,14 @@ class PosProcessamentoImagem:
                     candidate = symbol.copy()
                     c = 1 # encontrou 1 candidato
                     candidate_index = i # armazena index do candidato
-                    print('first candidate: ', candidate['index'])
-                    print('c: ', c)
-                    print('i: ', i)
+                    # print('first candidate: ', candidate['index'])
+                    # print('c: ', c)
+                    # print('i: ', i)
                 elif c == 1 and symbol['label'] == '10':
                     # SEGUNDO CANDIDATO
-                    print('candidate 2: ', symbol['index'])
-                    print('c: ', c)
-                    print('i: ', i)
+                    # print('candidate 2: ', symbol['index'])
+                    # print('c: ', c)
+                    # print('i: ', i)
 
                     '''
                     Fazer por %? A ordem importa.
@@ -51,16 +51,16 @@ class PosProcessamentoImagem:
                     # mean = (candidate['w'] + symbol['w']) / 2
 
                     diff = abs(candidate['w'] / symbol['w'])
-                    print('candidate width: ', candidate['w'])
-                    print('symbol width: ', symbol['w'])
-                    print('diff: ', diff)
+                    # print('candidate width: ', candidate['w'])
+                    # print('symbol width: ', symbol['w'])
+                    # print('diff: ', diff)
                     line1x = range(candidate['xmin'], candidate['xmax']+1)
                     line2x = range(symbol['xmin'], symbol['xmax']+1)
                     len_line1x = len(line1x)
                     len_line2x = len(line2x)
                     x_set = set(line1x) if len_line1x < len_line2x else set(line2x)
                     x_intersection = x_set.intersection(line1x if len_line1x >= len_line2x else line2x)
-                    print('x_intersection: ', x_intersection)
+                    # print('x_intersection: ', x_intersection)
 
                     # if x <= mean:
                     if x_intersection and diff <= 2 and diff >= 0.5:
